#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys, getpass
import socket
import termios
from pyeole.ihm import print_line, print_red
from creole.client import CreoleClient
from zephir.backend.lib_backend import CxPool
try:
    # ne devrait pas être utile car non exécuter en dehors du Zephir
    from zephir.zephir_conf.zephir_conf import adresse_zephir
    is_zephir = False
except:
    # Le serveur n'est pas inscrit sur un Zephir, on considere qu'on est sur un Zephir
    client = CreoleClient()
    adresse_zephir = client.get_creole('ssl_server_name')
    is_zephir = True
port = 7080
from zephir.lib_zephir import convert
from zephir.lib_zephir import xmlrpclib
from zephir.lib_zephir import EoleProxy
from zephir.lib_zephir import TransportEole
from zephir.lib_zephir import flushed_input


def make_group():
    cx_pool = CxPool()
    cu = cx_pool.create()
    cu.execute("""select libelle,id from modules""")
    infos = {}
    variante_infos = {}
    filename = 'exportation'
    server_infos = []
    for module_name in cu.fetchall():
        module, version = module_name[0].rsplit('-', 1)
        infos.setdefault(version, {})[module] = module_name[1]

    versions = list(infos.keys())
    versions.sort()
    print('Choix de la version :')
    for idx, version in enumerate(versions):
        print('{}: {}'.format(idx, version))
    idx = input('> ')
    version = versions[int(idx)]
    filename += '-' + version
    print()
    print('Choix du module :')
    modules = list(infos[version].keys())
    modules.sort()
    for idx, module in enumerate(modules):
        print('{}: {}'.format(idx, module))
    idx = input('> ')
    module = modules[int(idx)]
    filename += '-' + module
    print()
    cu.execute("select libelle,id from variantes where module = " + str(infos[version][module]))
    for variante_obj in cu.fetchall():
        variante_infos[variante_obj[0]] = variante_obj[1]
    print('Choix de la variante :')
    variantes = list(variante_infos.keys())
    variantes.sort()
    for idx, variante in enumerate(variantes):
        print('{}: {}'.format(idx, variante))
    idx_all = idx + 1
    print('{}: toutes les variantes'.format(idx_all))
    idx = int(input('> '))
    if idx == idx_all:
        variantes = list(variante_infos.values())
    else:
        filename += '-' + variantes[idx]
        variantes = [variante_infos[variantes[idx]]]
    print()
    for variante in variantes:
        cu.execute('select id,ip_publique,rne,libelle from serveurs where variante=' + str(variante))
        print("Liste des serveurs : ")
        for server in cu.fetchall():
            print('{} - {} - {} - {}'.format(server[0], server[1], server[2], server[3]))
            server_infos.append(server[0])
    return server_infos


def select_group(proxy, group_id):
    groups = get_groups(proxy)
    if group_id is None:
        print('Liste des groupes :')
        for grp_id, group_infos in groups.items():
            print(' - ' + str(grp_id) + ' : ' + group_infos[0])
        print( ' - N : Créer un nouveau groupe')

        while group_id is None:
            tmp_group_id = flushed_input("Numéro du groupe : ")
            if tmp_group_id == 'N':
                group_id = 'N'
                return make_group()
            else:
                try:
                    group_id = int(tmp_group_id)
                except Exception as err:
                    print(err)
                    continue
                if not group_id in groups:
                    print_red('Groupe inconnu')
                    group_id = None
                    sys.exit(1)
                return groups[group_id][1]
    else:
        return groups[group_id][1]


def get_groups(proxy):
    try:
        groups = {grp_id: (group_name, liste_serveurs) for grp_id, group_name, liste_serveurs in convert(proxy.serveurs.get_groups())[1]}
    except xmlrpclib.ProtocolError:
        print_red("""Erreur de permissions ou Zéphir non disponible""")
        sys.exit(1)
    except socket.error as e:
        print_red("""Erreur de connexion au serveur Zéphir (%s)""" % str(e))
        sys.exit(1)

    return groups


def get_connexion():
    """lecture d'un login/passwd pour l'application zephir
    """
    login_ok = 0
    user = "toto"
    while login_ok == 0 and user != "":
        try:
            # flush de l'entrée standard au cas où l'utilisateur aurait
            # tapé <entrée> pendant l'Upgrade
            termios.tcflush(sys.stdin, termios.TCIOFLUSH)
        except:
            pass
        user = flushed_input("Entrez votre login zephir (rien pour sortir) : ")
        if user != "":
            passwd = getpass.getpass("Mot de passe zephir pour %s : " % user)
            # création du proxy avec zephir
            proxy = EoleProxy("https://%s:%s@%s:%s" % (user, passwd, adresse_zephir, port), transport=TransportEole())
            login_ok = 1
            try:
                res = convert(proxy.get_permissions(user))
            except xmlrpclib.ProtocolError:
                login_ok = 0
                print_line("\n Erreur d'authentification \n")
        else:
            print_line("\n ! Abandon de la procédure ! \n")
            sys.exit(1)
    return proxy
