#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, socket
from pyeole.ansiprint import print_orange, print_red
from zephir.lib_zephir import xmlrpclib, flushed_input
from zephir_scripts.utils import get_connexion, select_group


def display_help():
    print("Autorise une connexion ssh d'un utilisateur sur un groupe de serveur")
    print("{} [numero du groupe] [--user utilisateur]".format(sys.argv[0]))

def argparser():
    # récupère l'ID du groupe
    arglen = len(sys.argv)
    if arglen == 1:
        return None, None
    if sys.argv[1] in ['-h', '--help']:
        display_help()
        sys.exit(0)
    try:
        group_id = int(sys.argv[1])
    except:
        print_red("\"{}\" n'est pas un ID de groupe valide".format(sys.argv[1]))
        display_help()
        sys.exit(1)

    if sys.argv[2] in ['-u', '--user']:
        user = sys.argv[3]
        return group_id, user

    return group_id, None

def main():
    group_id, user = argparser()

    proxy = get_connexion()
    liste_serveurs = select_group(proxy, group_id)

    if user is None:
        user = flushed_input("Utilisateur : ")

    ret = proxy.serveurs.authorize_user(user, liste_serveurs)
    if ret[0] == 1:
        print('Utilisateur {} autorisé à accéder en ssh aux serveurs {}'.format(user, liste_serveurs))
        print("Excecuter le script `configure_group.py [id_groupe] 5` pour envoyer la configuration aux serveurs")
    else:
        print_orange('Erreur : ' + str(ret[1]))
        sys.exit(1)

if __name__ == '__main__':
    main()
