#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, socket
from pyeole.ansiprint import print_orange, print_red
from zephir.lib_zephir import xmlrpclib, flushed_input
from zephir_scripts.utils import make_group, get_connexion, get_groups, select_group

def display_help():
    print("Envoi de la configuration sur un groupe de serveur")
    print("{} [numero du groupe] [numero action]".format(sys.argv[0]))

def argparser():
    # récupère l'ID du groupe
    arglen = len(sys.argv)
    if arglen == 1:
        return None, None
    if sys.argv[1] in ['-h', '--help']:
        display_help()
        sys.exit(0)
    try:
        group_id = int(sys.argv[1])
    except:
        print_red("\"{}\" n'est pas un ID de groupe valide".format(sys.argv[1]))
        display_help()
        sys.exit(1)

    if sys.argv[2]:
        num_content = int(sys.argv[2])
    else:
        num_content = None

    return group_id, num_content

def main():
    group_id, num_content = argparser()

    proxy = get_connexion()
    liste_serveurs = select_group(proxy, group_id)

    if num_content is None:
        print('0 > Tout')
        print('1 > Dictionnaires/templates/patchs/configuration/clés ssh')
        print('2 > Dictionnaires/templates/patchs')
        print('3 > Fichiers divers/paquets')
        print('4 > Configuration seulement (config.eol)')
        print('5 > Clés ssh seulement')
        num_content = int(flushed_input("Numéro : "))

    id_liste_serveurs = [{'id': idx} for idx in liste_serveurs]
    ret = proxy.uucp.configure_groupe(id_liste_serveurs, 0, num_content)

    # on affiche les erreurs si nécessaire
    if ret[1]:
        print_orange('Erreur : ' + str(ret[1]))
        exit(1)

    print("Demande d'envoi de la configuration exécuté sur les serveurs {}".format(liste_serveurs))

if __name__ == '__main__':
    main()
