#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, socket
from pyeole.ansiprint import print_orange, print_red
from zephir.lib_zephir import xmlrpclib, flushed_input
from zephir_scripts.utils import get_connexion, select_group


def display_help():
    print("Script de suppression des serveurs d'un groupe")
    print("{} [numero du groupe]".format(sys.argv[0]))


def argparser():
    # récupère l'ID du groupe
    arglen = len(sys.argv)
    if arglen == 1:
        return None
    if sys.argv[1] in ['-h', '--help']:
        display_help()
        sys.exit(0)
    try:
        group_id = int(sys.argv[1])
    except:
        print_red("\"{}\" n'est pas un ID de groupe valide".format(sys.argv[1]))
        display_help()
        sys.exit(1)

    return group_id


def main():
    group_id = argparser()

    proxy = get_connexion()
    liste_serveurs = select_group(proxy, group_id)
    if not liste_serveurs:
        print("Aucun serveur trouvé dans le groupe")
        sys.exit(1)

    for id_serv in liste_serveurs :
        ret = proxy.serveurs.del_serveur(id_serv)
        if ret[1]:
            if ret[1] == "ok":
                 print('Les serveurs {} ont été supprimés'.format(liste_serveurs))
            else:
                print_orange('Erreur : ' + str(ret[1]))
                sys.exit(1)


if __name__ == '__main__':
    main()
