#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, socket
from pyeole.ansiprint import print_orange, print_red
from zephir.lib_zephir import xmlrpclib, flushed_input
from zephir_scripts.utils import make_group, get_connexion, get_groups, select_group

def display_help():
    print("Exécute un script Zéphir sur un groupe de serveur")
    print("{} [numero du groupe] [--script nom_du_script --args arguments]".format(sys.argv[0]))

def argparser():
    # récupère l'ID du groupe
    arglen = len(sys.argv)
    if arglen == 1:
        return None, None, None
    if sys.argv[1] in ['-h', '--help']:
        display_help()
        sys.exit(0)
    try:
        group_id = int(sys.argv[1])
    except:
        print_red("\"{}\" n'est pas un ID de groupe valide".format(sys.argv[1]))
        display_help()
        sys.exit(1)

    if sys.argv[2] in ['-s', '--script']:
        script = sys.argv[3]
    else:
        script = None

    if script and sys.argv[4] in ['-a', '--args']:
        params = " ".join(sys.argv[5:])
    else:
        params = None

    return group_id, script, params

def main():
    group_id, script, params = argparser()

    proxy = get_connexion()
    liste_serveurs = select_group(proxy, group_id)

    if script is None:
        script = flushed_input("Script à executer : ")
        if params is None:
            params = flushed_input("Paramètres : ")


    if params is None: params = ""
    ret = proxy.uucp.exec_script(liste_serveurs, script, params)

    # on affiche les erreurs si nécessaire
    if ret[1]:
        print_orange('Erreur : ' + str(ret[1]))

    print('Script {} {} exécuté sur les serveurs {}'.format(script, params, liste_serveurs))

if __name__ == '__main__':
    main()
