#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, socket
from pyeole.ansiprint import print_orange, print_red
from zephir.lib_zephir import xmlrpclib, flushed_input
from zephir_scripts.utils import get_connexion, select_group


def display_help():
    print("Script de modification de la valeur de polling des serveurs d'un groupe")
    print("{} [numero du groupe] [--polling valeur".format(sys.argv[0]))


def argparser():
    # récupère l'ID du groupe
    arglen = len(sys.argv)
    if arglen == 1:
        return None, None
    if sys.argv[1] in ['-h', '--help']:
        display_help()
        sys.exit(0)

    try:
        group_id = int(sys.argv[1])
    except:
        print_red("\"{}\" n'est pas un ID de groupe valide".format(sys.argv[1]))
        display_help()
        sys.exit(1)

    if sys.argv[2] in ['-p', '--polling']:
        polling = sys.argv[3]
        return group_id, polling

    return group_id, None


def main():
    group_id, polling = argparser()

    proxy = get_connexion()
    liste_serveurs = select_group(proxy, group_id)

    if polling is None :
        polling = flushed_input("Durée du polling (en min) : ")

    ret = proxy.serveurs.groupe_params(liste_serveurs,{'timeout': str(int(polling)*60)})
    # on affiche les erreurs si nécessaire
    if ret[1]:
        if ret[1] != "OK":
            print_orange('Erreur : ' + str(ret[1]))
            sys.exit(1)
    print('Durée de polling mise à jour sur les serveurs {}'.format(liste_serveurs))


if __name__ == '__main__':
    main()
