#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, socket
from pyeole.ansiprint import print_orange, print_red
from zephir.lib_zephir import xmlrpclib, flushed_input, convert
from zephir_scripts.utils import get_connexion, select_group


def display_help():
    print("Modification de la valeur d'une variable d'un serveur")
    print("{} [numero du groupe] [--var nom_variable --value valeur --save]".format(sys.argv[0]))


def argparser():
    # récupère l'ID du groupe
    arglen = len(sys.argv)

    if arglen == 1:
        return  None, None, None
    if sys.argv[1] in ['-h', '--help']:
        display_help()
        sys.exit(0)

    try:
        group_id = int(sys.argv[1])
    except:
        print_red("\"{}\" n'est pas un ID de groupe valide".format(sys.argv[1]))
        display_help()
        sys.exit(1)

    if sys.argv[2] in ['-v', '--var']:
        varc = sys.argv[3]
        if sys.argv[4] in ['-l', '--value']:
            valvar = sys.argv[5]
            return group_id, varc, valvar
        else:
            return  group_id, varc, None,

    return  None, None, None


def main():
    # import des fonctions communes de Zéphir client
    group_id, varc, valvar = argparser()

    proxy = get_connexion()
    liste_serveurs = select_group(proxy, group_id)

    # on récupère toutes les master/slaves du groupe de serveurs
    params = convert(proxy.serveurs.get_groupe_vars(liste_serveurs, True))


    if varc is None :
        print()
        print('Liste des variables modifiables dans le groupe :')
        list_vars = params[1][3]
        for var in list_vars:
            print(' - ' + var)
        varc = flushed_input("Variable à modifier : ")

    if valvar is None :
        valvar = flushed_input("Valeur de la variable (séparateur |): ")
    ret = proxy.serveurs.set_groupe_var(liste_serveurs, varc, valvar, False)
    # on affiche les erreurs si nécessaire
    if ret[1]:
        if ret[1] != "OK":
            print_orange('Erreur : ' + str(ret[1]))
            sys.exit(1)
    print('Variable {} mis à jour sur les serveurs {}'.format(varc, liste_serveurs))


if __name__ == '__main__':
    main()
